lcvtoolbox.vision.geometry.projection.project\_masks\_on\_road.GPSCoordinates
=============================================================================

.. currentmodule:: lcvtoolbox.vision.geometry.projection.project_masks_on_road

.. autoclass:: GPSCoordinates
   :members:
   :undoc-members:
   :show-inheritance:
   :inherited-members:
   :special-members: __init__, __str__, __repr__

   
   
   .. rubric:: Methods

   .. autosummary::
      :nosignatures:
   
      ~GPSCoordinates.__init__
      ~GPSCoordinates.construct
      ~GPSCoordinates.copy
      ~GPSCoordinates.dict
      ~GPSCoordinates.from_orm
      ~GPSCoordinates.json
      ~GPSCoordinates.model_construct
      ~GPSCoordinates.model_copy
      ~GPSCoordinates.model_dump
      ~GPSCoordinates.model_dump_json
      ~GPSCoordinates.model_json_schema
      ~GPSCoordinates.model_parametrized_name
      ~GPSCoordinates.model_post_init
      ~GPSCoordinates.model_rebuild
      ~GPSCoordinates.model_validate
      ~GPSCoordinates.model_validate_json
      ~GPSCoordinates.model_validate_strings
      ~GPSCoordinates.parse_file
      ~GPSCoordinates.parse_obj
      ~GPSCoordinates.parse_raw
      ~GPSCoordinates.schema
      ~GPSCoordinates.schema_json
      ~GPSCoordinates.update_forward_refs
      ~GPSCoordinates.validate
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~GPSCoordinates.model_computed_fields
      ~GPSCoordinates.model_config
      ~GPSCoordinates.model_extra
      ~GPSCoordinates.model_fields
      ~GPSCoordinates.model_fields_set
      ~GPSCoordinates.latitude
      ~GPSCoordinates.longitude
      ~GPSCoordinates.heading
   
   